@@ -35,6 +35,7 @@
 #include "mainwindow.h"
 #include "aboutdata.h"
 
+#include "view/padwidget.h"
 #include "view/searchbar.h"
 #include "view/tabwidget.h"
 #include "view/keylistcontroller.h"
@@ -81,6 +82,7 @@
 #include <QMimeData>
 #include <QDesktopServices>
 #include <QDir>
+#include <QStackedWidget>
 #include <QStatusBar>
 #include <QLabel>
 
@@ -219,7 +221,7 @@ public:
 
     void forceUpdateCheck()
     {
-        UpdateNotification::checkUpdate(q, true);
+        UpdateNotification::forceUpdateCheck(q);
     }
 
     void openCompendium()
@@ -252,16 +254,27 @@ public:
 
     void toggleSmartcardView()
     {
-        if (ui.scWidget->isVisible()) {
-            ui.scWidget->hide();
-            ui.searchBar->show();
-            ui.tabWidget.show();
-        } else {
-            ui.scWidget->show();
-            ui.searchBar->hide();
-            ui.tabWidget.hide();
-            ui.welcomeWidget->hide();
+        if (ui.stackWidget->currentWidget() == ui.scWidget) {
+            ui.stackWidget->setCurrentWidget(ui.searchTab);
+            checkWelcomePage();
+            return;
         }
+        ui.stackWidget->setCurrentWidget(ui.scWidget);
+    }
+
+    void togglePadView()
+    {
+        if (ui.stackWidget->currentWidget() == ui.padWidget) {
+            ui.stackWidget->setCurrentWidget(ui.searchTab);
+            checkWelcomePage();
+            return;
+        }
+        if (!ui.padWidget) {
+            ui.padWidget = new PadWidget;
+            ui.stackWidget->addWidget(ui.padWidget);
+        }
+        ui.stackWidget->setCurrentWidget(ui.padWidget);
+        ui.stackWidget->resize(ui.padWidget->sizeHint());
     }
 
 private:
@@ -274,17 +287,14 @@ private:
 
     void checkWelcomePage()
     {
-        if (ui.scWidget->isVisible()) {
+        const auto curWidget = ui.stackWidget->currentWidget();
+        if (curWidget == ui.scWidget || curWidget == ui.padWidget) {
            return;
         }
         if (KeyCache::instance()->keys().empty()) {
-            ui.searchBar->hide();
-            ui.tabWidget.hide();
-            ui.welcomeWidget->show();
+            ui.stackWidget->setCurrentWidget(ui.welcomeWidget);
         } else {
-            ui.welcomeWidget->hide();
-            ui.searchBar->show();
-            ui.tabWidget.show();
+            ui.stackWidget->setCurrentWidget(ui.searchTab);
         }
     }
 
@@ -292,11 +302,13 @@ private:
     Kleo::KeyListController controller;
     bool firstShow : 1;
     struct UI {
-
+        QWidget *searchTab;
         TabWidget tabWidget;
         SearchBar *searchBar;
+        PadWidget *padWidget;
         SmartCardWidget *scWidget;
         WelcomeWidget *welcomeWidget;
+        QStackedWidget *stackWidget;
         explicit UI(MainWindow *q);
     } ui;
     QAction *focusToClickSearchAction;
@@ -304,27 +316,33 @@ private:
 };
 
 MainWindow::Private::UI::UI(MainWindow *q)
-    : tabWidget(q)
+    : tabWidget(q), padWidget(nullptr)
 {
     KDAB_SET_OBJECT_NAME(tabWidget);
 
-    QWidget *mainWidget = new QWidget;
-    QVBoxLayout *vbox = new QVBoxLayout;
+    searchTab = new QWidget;
+    QVBoxLayout *vbox = new QVBoxLayout(searchTab);
     vbox->setSpacing(0);
-    mainWidget->setLayout(vbox);
     searchBar = new SearchBar;
     vbox->addWidget(searchBar);
     tabWidget.connectSearchBar(searchBar);
     vbox->addWidget(&tabWidget);
+
+    QWidget *mainWidget = new QWidget;
+    auto mainLayout = new QVBoxLayout(mainWidget);
+    stackWidget = new QStackedWidget;
+
+    mainLayout->addWidget(stackWidget);
+
+    stackWidget->addWidget(searchTab);
+
     new KeyCacheOverlay(mainWidget, q);
 
     scWidget = new SmartCardWidget();
-    vbox->addWidget(scWidget);
-    scWidget->hide();
+    stackWidget->addWidget(scWidget);
 
     welcomeWidget = new WelcomeWidget();
-    vbox->addWidget(welcomeWidget);
-    welcomeWidget->hide();
+    stackWidget->addWidget(welcomeWidget);
 
     q->setCentralWidget(mainWidget);
 }
@@ -350,6 +368,8 @@ MainWindow::Private::Private(MainWindow *qq)
     ui.tabWidget.setFlatModel(flatModel);
     ui.tabWidget.setHierarchicalModel(hierarchicalModel);
 
+    ui.stackWidget->setCurrentWidget(ui.searchTab);
+
     setupActions();
 
     connect(&controller, SIGNAL(contextMenuRequested(QAbstractItemView*,QPoint)), q, SLOT(slotContextMenuRequested(QAbstractItemView*,QPoint)));
@@ -403,6 +423,10 @@ void MainWindow::Private::setupActions()
             "gpg4win-compact", q, SLOT(openCompendium()), QString(), false, true
         },
 #endif
+        {
+            "pad_view", i18nc("Title for a generic data input / output area supporting text actions.", "Notepad"),
+            i18n("Switch to Pad view."), "edittext", q, SLOT(togglePadView()), QString(), true, true
+        },
         // most have been MOVED TO keylistcontroller.cpp
 #if 0
         {
